local Sushi = LibStub('Sushi-2.0')
local Description = Sushi:NewWidgetClass('Description', {
	frameType = 'Frame',
	insets = {top = 5, bottom = 20, left = 12, right = 12},
	version = 1,
})

if not Description then
	return
end


--[[ Events ]]--

function Description:OnCreate()
	local Text = self:CreateFontString(self:GetName() .. 'Text')
	Text:SetPoint('TOPLEFT')
	Text:SetJustifyH('LEFT')
	
	self.SetRealWidth = getmetatable(self).__index.SetWidth
	self.SetLabel = self.SetText
	self.GetLabel = self.GetText
	self.Text = Text
end

function Description:OnAcquire()
	self:SetWidth(true)
	self:UpdateFont()
end

function Description:OnRelease()
	self.disabled, self.small = nil, nil
	self.Text:SetText(nil)
end


--[[ Text ]]--

function Description:SetText(text)
	self.Text:SetText(text)
	self:UpdateHeight()
end

function Description:GetText(text)
	return self.Text:GetText()
end


--[[ Width & Height ]]--

function Description:SetWidth(width)
	if width == true then
		local parent = self:GetParent()
		width = parent and parent:GetWidth() - 12
	end
	
	width = width or 0
	self.Text:SetWidth(width)
	self:SetRealWidth(width)
	self:UpdateHeight()
end

function Description:UpdateHeight()
	self:SetHeight(self.Text:GetHeight())
end


--[[ Font ]]--

function Description:SetDisabled(disabled)
	self.disabled = disabled
	self:UpdateFont()
end

function Description:IsDisabled()
	return self.disabled
end

function Description:SetSmall(small)
	self.small = small
	self:UpdateFont()
end

function Description:IsSmall()
	return self.small
end

function Description:UpdateFont()
	local font
	if not self:IsDisabled() then
		font = 'Highlight'
	else
		font = 'Disable'
	end
	if self:IsSmall() then
		font = font ..'Small'
	end
	
	self.Text:SetFontObject('GameFont' .. font)
	self:UpdateHeight()
end


--[[ Embedding ]]--

Description:UpdateEmbeds()